@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 1.05.
 package XML::Compile::Schema::XmlReader;
 use vars '$VERSION';
-$VERSION = '0.85';
+$VERSION = '0.86';
 
 
 use strict;
@@ -185,7 +185,7 @@ sub choice($@)
           # a choice, instead on choice itself.  That always succeeds.
           foreach my $some (values %do)
           {   try { $some->(undef) };
-              $@ or return ();
+              $@ or return;
           }
 
           $local
@@ -206,9 +206,10 @@ sub choice($@)
 
           my @special_errors;
           foreach (@specials)
-          {   my @d = try { $_->($tree) };
-              $@ or return @d;
-              push @special_errors, $@->wasFatal->message;
+          {
+              my @d = try { $_->($tree) };
+              return @d if !$@ && @d;
+              push @special_errors, $@->wasFatal->message if $@;
           }
 
           foreach my $some (values %do, @specials)
@@ -516,15 +517,14 @@ sub element_default
 
 sub element_fixed
 {   my ($path, $args, $ns, $childname, $do, $fixed) = @_;
-    my $fix  = $do->($fixed);
+    my ($tag, $fix) = $do->($fixed);
 
     sub { my $tree = shift;
           my ($label, $value)
             = $tree && $tree->nodeLocal eq $childname ? $do->($tree) : ();
 
           defined $value
-              or error __x"element `{name}' with fixed value `{fixed}' missing at {path}"
-                     , name => $childname, fixed => $fix, path => $path;
+              or return ($tag => $fix);
 
           $value eq $fix
               or error __x"element `{name}' must have fixed value `{fixed}', got `{value}' at {path}"
@@ -604,18 +604,39 @@ sub tagged_element
 #
 
 sub mixed_element
-{   my ($path, $args, $tag, $attrs, $attrs_any) = @_;
+{   my ($path, $args, $tag, $elems, $attrs, $attrs_any) = @_;
     my @attrs = (odd_elements(@$attrs), @$attrs_any);
+    my $mixed = $args->{mixed_elements}
+         or panic "how to handle mixed?";
 
-    @attrs
-    ? sub { my $tree   = shift or return ();
+      ref $mixed eq 'CODE'
+    ? sub { my $tree = shift or return;
+            my $node = $tree->node or return;
+            my @v = $mixed->($node);
+            @v ? ($tag => $v[0]) : ();
+          }
+    : $mixed eq 'XML_NODE'
+    ? sub { $_[0] ? ($tag => $_[0]->node) : () }
+    : $mixed eq 'ATTRIBUTES'
+    ? sub { my $tree   = shift or return;
             my $node   = $tree->node;
             my @pairs  = map {$_->($node)} @attrs;
             ($tag => {_ => $node, @pairs});
+          } 
+    : $mixed eq 'TEXTUAL'
+    ? sub { my $tree   = shift or return;
+            my $node   = $tree->node;
+            my @pairs  = map {$_->($node)} @attrs;
+            ($tag => {_ => $node->textContent, @pairs});
+          } 
+    : $mixed eq 'XML_STRING'
+    ? sub { my $tree   = shift or return;
+            my $node   = $tree->node or return;
+            ($tag => $node->toString);
           }
-    : sub { my $tree   = shift;
-            $tree ? ($tag => $tree->node) : ();
-          };
+    : $mixed eq 'STRUCTURAL'
+    ? panic "mixed structural handled as normal element"
+    : panic "unknown mixed_elements value $mixed";
 }
 
 #
@@ -756,21 +777,6 @@ sub attribute_fixed
 {   my ($path, $args, $ns, $tag, $do, $fixed) = @_;
     my $def  = $do->($fixed);
 
-    sub { my $node = $_[0]->getAttributeNodeNS($ns, $tag);
-          my $value = defined $node ? $do->($node) : undef;
-
-          defined $value && $value eq $def
-              or error __x"value of attribute `{tag}' is fixed to `{fixed}', not `{value}' at {path}"
-                  , tag => $tag, fixed => $def, value => $value, path => $path;
-
-          ($tag => $def);
-        };
-}
-
-sub attribute_fixed_optional
-{   my ($path, $args, $ns, $tag, $do, $fixed) = @_;
-    my $def  = $do->($fixed);
-
     sub { my $node  = $_[0]->getAttributeNodeNS($ns, $tag)
               or return ($tag => $def);
 
@@ -789,6 +795,7 @@ sub substgroup
 {   my ($path, $args, $type, %do) = @_;
 
     keys %do or return bless sub { () }, 'BLOCK';
+#warn "SUBST $type; ",join '#', @_;
 
     bless
     sub { my $tree  = shift;
@@ -949,13 +956,13 @@ sub _decode_after($$)
       $call eq 'PRINT_PATH' ? sub {print "$_[2]\n"; $_[1] }
     : $call eq 'XML_NODE'  ?
       sub { my $h = $_[1];
-            ref $h eq 'HASH' or $h = { _ => $h };
+            $h = { _ => $h } if ref $h ne 'HASH';
             $h->{_XML_NODE} = $_[0];
             $h;
           }
     : $call eq 'ELEMENT_ORDER' ?
       sub { my ($xml, $h) = @_;
-            ref $h eq 'HASH' or $h = { _ => $h };
+            $h = { _ => $h } if ref $h ne 'HASH';
             my @order = map {type_of_node $_}
                 grep { $_->isa('XML::LibXML::Element') }
                     $xml->childNodes;
@@ -964,7 +971,7 @@ sub _decode_after($$)
           }
     : $call eq 'ATTRIBUTE_ORDER' ?
       sub { my ($xml, $h) = @_;
-            ref $h eq 'HASH' or $h = { _ => $h };
+            $h = { _ => $h } if ref $h ne 'HASH';
             my @order = map {$_->nodeName} $xml->attributes;
             $h->{_ATTRIBUTE_ORDER} = \@order;
             $h;
